{ config, lib, pkgs, osConfig, ... }:
let
  home-manager = builtins.fetchTarball "https://github.com/nix-community/home-manager/archive/release-24.11.tar.gz";
in
{

  imports = [
    (import "${home-manager}/nixos")
  ];

  home-manager.backupFileExtension = "backup";
  home-manager.useGlobalPkgs = true;
  home-manager.useUserPackages = true;

  home-manager.users.zulumann = {
    home.stateVersion = "24.11";
    home.homeDirectory = "/home/zulumann";
    home.packages = with pkgs; [     
      neofetch
   ];

    programs.home-manager.enable = true;

    home.file = {
      ".profile" = {
      text = ''
      export GTK_THEME=Arc-Dark 
      '';
      };

      ".rsync-exlude" = {
      text = ''
      - Downloads
      - Games
      - Share-Cloud
      - Share-Priv
      - Share-SMB
      - Share-VM
      - Sync
      - VM-Image
      - Code Cache
      - cache*
      - Cache*
      - Cache_*
      - *_cache
      - *Cache
      - DawnGraphiteCache
      - log*
      - logs
      - tmp
      - Trash
      + .config
      - .config/syncthing
      - .config/unity3d
      - .config/ownCloud
      + .local
      - .local/state
      - .local/share/containers
      - .local/share/flatpak
      - .local/share/keyrings
      - .local/share/nomic.ai
      - .local/share/Steam
      + .jd2
      + .conkyrc
      - .*
      - *.LOG
      - LOG
      - *.old
      '';
      };
    };
  };

}
